machineid

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2021 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MachineID

func MachineID(root string) string

MachineID returns the uuid specified `/etc/machine-id` it first prepends the provided root to the filepath if there is an error reading the file it returns the empty string

Types

This section is empty.

Jump to